<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       https://www.kartechify.com/
 * @since      1.0.0
 *
 * @package    Wc_Change_Filter_By_Price_Display
 * @subpackage Wc_Change_Filter_By_Price_Display/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Wc_Change_Filter_By_Price_Display
 * @subpackage Wc_Change_Filter_By_Price_Display/admin
 * @author     Kartik Parmar <kartechify@gmail.com>
 */
class Wc_Change_Filter_By_Price_Display_Admin {

	/**
	 * The Plugin Name
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The name of plugin.
	 */
	private $name;

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version, $name ) {

		$this->plugin_name = $plugin_name;
		$this->version     = $version;
		$this->name        = $name;

	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function cfpd_plugin_settings_link( $links ) {

		$setting_text = __( 'Settings', $this->plugin_name );
		$setting_link['settings'] = '<a href="'. esc_url( get_admin_url( null, 'admin.php?page=wc-settings&tab=products&section=change_filter_products_by_price_display') ) .'">' . $setting_text . '</a>';
		$links = $setting_link + $links;
		return $links;

	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Wc_Change_Filter_By_Price_Display_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Wc_Change_Filter_By_Price_Display_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/wc-change-filter-by-price-display-admin.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Wc_Change_Filter_By_Price_Display_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Wc_Change_Filter_By_Price_Display_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/wc-change-filter-by-price-display-admin.js', array( 'jquery' ), $this->version, false );

	}

	/**
	 * Display notice when WooCommerce is Deactive.
	 *
	 * @since    1.0.0
	 */
	public function cfpd_error_notice() {
		?>
		<div class="error">
			<p><?php esc_html_e( 'Extend Filter Products By Price Widget will work only if the WooCommerce Plugin is installed and active.', $this->plugin_name ); ?></p>
		</div>
		<?php
	}

	/**
	 * Registering the section in Products tab.
	 *
	 * @since 1.0.0
	 */
	public function change_filter_by_price_display_add_settings_tab( $settings_tab ) {
		$settings_tab['change_filter_products_by_price_display'] = __( 'Extend Filter Products By Price Widget', $this->plugin_name );
		return $settings_tab;
	}

	/**
	 * Adding Fields in Sort Products in Cart/Order section.
	 *
	 * @since 1.0.0
	 */
	public function change_filter_by_price_display_get_settings( $settings, $current_section ) {
		$custom_settings = array();

		if ( 'change_filter_products_by_price_display' === $current_section ) {

			$custom_settings = array(
				array(
					'name' => __( 'Extend Filter Products By Price Widget', $this->plugin_name ),
					'type' => 'title',
					'desc' => __( 'This section allows you to change appearance of Filter Products by Price WooCommerce Widget.', $this->plugin_name ),
					'id'   => 'cfpd_change_filter_products_by_price_display',
				),
				array(
					'name' => __( 'Enable', $this->plugin_name ),
					'type' => 'checkbox',
					'desc' => __( 'Enabling this option override below values in Filter Products by Price Widget.', $this->plugin_name ),
					'id'   => 'cfpd_enable_change_filter_products_by_price_display',

				),
				array(
					'name'              => __( 'Minimum Price', $this->plugin_name ),
					'type'              => 'number',
					'desc'              => __( 'Set minimum price to be displayed in price range', $this->plugin_name ),
					'desc_tip'          => true,
					'custom_attributes' => array(
						'step' => 1,
						'min'  => 0,
					),
					'id'                => 'cfpd_minimum_price',
					'css'               => 'width:100px;',
				),
				array(
					'name'              => __( 'Maximum Price', $this->plugin_name ),
					'type'              => 'number',
					'desc'              => __( 'Set maximum price to be displayed in price range', $this->plugin_name ),
					'desc_tip'          => true,
					'custom_attributes' => array(
						'step' => 1,
						'min'  => 0,
					),
					'id'                => 'cfpd_maximum_price',
					'css'               => 'width:100px;',
				),
				array(
					'name'              => __( 'Steps', $this->plugin_name ),
					'type'              => 'number',
					'desc'              => __( 'Set step to be considered in price range', $this->plugin_name ),
					'desc_tip'          => true,
					'custom_attributes' => array(
						'step' => 1,
						'min'  => 0,
					),
					'id'                => 'cfpd_step_price',
					'css'               => 'width:100px;',
				),
				array(
					'name'     => __( 'Slider Color', $this->plugin_name ),
					'type'     => 'color',
					'desc'     => __( 'Color of the price range slider', $this->plugin_name ),
					'desc_tip' => true,
					'css'      => 'width:6em;',
					'id'       => 'cfpd_color',
				),
				array(
					'title'    => __( 'Content before Filter Products by Price', $this->plugin_name ),
					'desc_tip' => __( 'Add content before Filter Products by Price widget form. HTML are allowed', $this->plugin_name ),
					'id'       => 'cfpd_content_before_filter_product_by_price',
					'type'     => 'textarea',
					'css'      => 'min-width: 50%; height: 75px;',
				),
				array(
					'title'    => __( 'Content after Filter Products by Price', $this->plugin_name ),
					'desc_tip' => __( 'Add content after Filter Products by Price widget form. HTML are allowed', 'woocommerce' ),
					'id'       => 'cfpd_content_after_filter_product_by_price',
					'type'     => 'textarea',
					'css'      => 'min-width: 50%; height: 75px;',
				),
				array(
					'type' => 'sectionend',
					'id'   => 'change_filter_products_by_price_display_section',
				),
			);

			return $custom_settings;
		} else {
			return $settings;
		}
	}
}
