<?php

/**
 * The file that defines the core plugin class
 *
 * A class definition that includes attributes and functions used across both the
 * public-facing side of the site and the admin area.
 *
 * @link       https://www.kartechify.com/
 * @since      1.0.0
 *
 * @package    Wc_Change_Filter_By_Price_Display
 * @subpackage Wc_Change_Filter_By_Price_Display/includes
 */

/**
 * The core plugin class.
 *
 * This is used to define internationalization, admin-specific hooks, and
 * public-facing site hooks.
 *
 * Also maintains the unique identifier of this plugin as well as the current
 * version of the plugin.
 *
 * @since      1.0.0
 * @package    Wc_Change_Filter_By_Price_Display
 * @subpackage Wc_Change_Filter_By_Price_Display/includes
 * @author     Kartik Parmar <kartechify@gmail.com>
 */
class Wc_Change_Filter_By_Price_Display {

	/**
	 * The loader that's responsible for maintaining and registering all hooks that power
	 * the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      Wc_Change_Filter_By_Price_Display_Loader    $loader    Maintains and registers all hooks for the plugin.
	 */
	protected $loader;

	/**
	 * The unique identifier of this plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $plugin_name    The string used to uniquely identify this plugin.
	 */
	protected $plugin_name;

	/**
	 * The current version of the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $version    The current version of the plugin.
	 */
	protected $version;

	/**
	 * Define the core functionality of the plugin.
	 *
	 * Set the plugin name and the plugin version that can be used throughout the plugin.
	 * Load the dependencies, define the locale, and set the hooks for the admin area and
	 * the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function __construct() {
		if ( defined( 'WC_CHANGE_FILTER_BY_PRICE_DISPLAY_VERSION' ) ) {
			$this->version = WC_CHANGE_FILTER_BY_PRICE_DISPLAY_VERSION;
		} else {
			$this->version = '1.0';
		}
		$this->plugin_name = 'wc-change-filter-by-price-display';
		$this->name        = 'Change Filter By Price Display for WooCommerce';

		$this->load_dependencies();
		$this->set_locale();
		$this->define_admin_hooks();
		$this->define_public_hooks();

		//add_action( 'init', array( $this, 'plugin_init' ), 100 );

	}

	/* public static function plugin_init() {
		
		$widget   = new WC_Widget_Price_Filter();
		$settings = $widget->settings;

		$settings['min'] = array(
			'type'  => 'text',
			'std'   => '',
			'label' => __( 'Min', 'woocommerce' ),
		);

		$settings['max'] = array(
			'type'  => 'text',
			'std'   => '',
			'label' => __( 'Max', 'woocommerce' ),
		);

		$widget->settings = $settings;
	} */

	/**
	 * Load the required dependencies for this plugin.
	 *
	 * Include the following files that make up the plugin:
	 *
	 * - Wc_Change_Filter_By_Price_Display_Loader. Orchestrates the hooks of the plugin.
	 * - Wc_Change_Filter_By_Price_Display_i18n. Defines internationalization functionality.
	 * - Wc_Change_Filter_By_Price_Display_Admin. Defines all hooks for the admin area.
	 * - Wc_Change_Filter_By_Price_Display_Public. Defines all hooks for the public side of the site.
	 *
	 * Create an instance of the loader which will be used to register the hooks
	 * with WordPress.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function load_dependencies() {

		/**
		 * The class responsible for orchestrating the actions and filters of the
		 * core plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-wc-change-filter-by-price-display-loader.php';

		/**
		 * The class responsible for defining internationalization functionality
		 * of the plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-wc-change-filter-by-price-display-i18n.php';

		/**
		 * The class responsible for defining all actions that occur in the admin area.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/class-wc-change-filter-by-price-display-admin.php';

		/**
		 * The class responsible for defining all actions that occur in the public-facing
		 * side of the site.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'public/class-wc-change-filter-by-price-display-public.php';

		$this->loader = new Wc_Change_Filter_By_Price_Display_Loader();

	}

	/**
	 * Define the locale for this plugin for internationalization.
	 *
	 * Uses the Wc_Change_Filter_By_Price_Display_i18n class in order to set the domain and to register the hook
	 * with WordPress.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function set_locale() {

		$plugin_i18n = new Wc_Change_Filter_By_Price_Display_i18n();

		$this->loader->add_action( 'plugins_loaded', $plugin_i18n, 'load_plugin_textdomain' );

	}

	/**
	 * Register all of the hooks related to the admin area functionality
	 * of the plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function define_admin_hooks() {

		$plugin_admin = new Wc_Change_Filter_By_Price_Display_Admin( $this->get_plugin_name(), $this->get_version(), $this->get_name() );

		if ( $this->cfpd_is_woocommerce_activated() ) {
			$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'enqueue_styles' );

			$this->loader->add_filter( 'plugin_action_links_' . CFPD_PLUGIN_BASENAME, $plugin_admin, 'cfpd_plugin_settings_link' );

			$this->loader->add_action( 'woocommerce_get_sections_products', $plugin_admin, 'change_filter_by_price_display_add_settings_tab' );
			$this->loader->add_action( 'woocommerce_get_settings_products', $plugin_admin, 'change_filter_by_price_display_get_settings', 10, 2 );

			$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'enqueue_styles' );
			$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'enqueue_scripts' );

		} else {
			$this->loader->add_action( 'admin_notices', $plugin_admin, 'cfpd_error_notice' );
		}
	}

	/**
	 * Check if WooCommerce is activated.
	 *
	 * @since 1.10
	 * @return bool $check true is WooCommerce is active else false.
	 */
	public static function cfpd_is_woocommerce_activated() {

		$blog_plugins         = get_option( 'active_plugins', array() );
		$site_plugins         = get_site_option( 'active_sitewide_plugins', array() );
		$woocommerce_basename = 'woocommerce/woocommerce.php';
		$check                = false;

		if ( ( in_array( $woocommerce_basename, $blog_plugins ) || isset( $site_plugins[ $woocommerce_basename ] ) ) ) {
			return true;
		}
		return $check;
	}

	/**
	 * Register all of the hooks related to the admin area functionality
	 * of the plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function define_woocommerce_hooks() {

	}

	/**
	 * Register all of the hooks related to the public-facing functionality
	 * of the plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function define_public_hooks() {

		$plugin_public = new Wc_Change_Filter_By_Price_Display_Public( $this->get_plugin_name(), $this->get_version() );

		$this->loader->add_action( 'wp_enqueue_scripts', $plugin_public, 'enqueue_styles' );
		$this->loader->add_action( 'wp_enqueue_scripts', $plugin_public, 'enqueue_scripts' );

		if ( 'yes' === get_option( 'cfpd_enable_change_filter_products_by_price_display', '' ) ) {
			$this->loader->add_action( 'wp_head', $plugin_public, 'cfpd_wp_head' );
			$this->loader->add_action( 'woocommerce_widget_price_filter_start', $plugin_public, 'cfpd_woocommerce_widget_price_filter_start' );
			$this->loader->add_action( 'woocommerce_widget_price_filter_end', $plugin_public, 'cfpd_woocommerce_widget_price_filter_end' );
			$this->loader->add_filter( 'woocommerce_price_filter_widget_step', $plugin_public, 'cfpd_woocommerce_price_filter_widget_step', 10, 1 );
			$this->loader->add_filter( 'woocommerce_price_filter_widget_min_amount', $plugin_public, 'cfpd_woocommerce_price_filter_widget_min_amount', 10, 1 );
			$this->loader->add_filter( 'woocommerce_price_filter_widget_max_amount', $plugin_public, 'cfpd_woocommerce_price_filter_widget_max_amount', 10, 1 );
		}
	}

	/**
	 * Run the loader to execute all of the hooks with WordPress.
	 *
	 * @since    1.0.0
	 */
	public function run() {
		$this->loader->run();
	}

	/**
	 * The name of the plugin used to uniquely identify it within the context of
	 * WordPress and to define internationalization functionality.
	 *
	 * @since     1.0.0
	 * @return    string    The name of the plugin.
	 */
	public function get_plugin_name() {
		return $this->plugin_name;
	}

	/**
	 * The name of the plugin.
	 *
	 * @since     1.0.0
	 * @return    string    The name of the plugin.
	 */
	public function get_name() {
		return $this->name;
	}

	/**
	 * The reference to the class that orchestrates the hooks with the plugin.
	 *
	 * @since     1.0.0
	 * @return    Wc_Change_Filter_By_Price_Display_Loader    Orchestrates the hooks of the plugin.
	 */
	public function get_loader() {
		return $this->loader;
	}

	/**
	 * Retrieve the version number of the plugin.
	 *
	 * @since     1.0.0
	 * @return    string    The version number of the plugin.
	 */
	public function get_version() {
		return $this->version;
	}

}
