<?php
/**
 * The public-facing functionality of the plugin.
 *
 * @link       https://www.kartechify.com/
 * @since      1.0.0
 *
 * @package    Wc_Change_Filter_By_Price_Display
 * @subpackage Wc_Change_Filter_By_Price_Display/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Wc_Change_Filter_By_Price_Display
 * @subpackage Wc_Change_Filter_By_Price_Display/public
 * @author     Kartik Parmar <kartechify@gmail.com>
 */
class Wc_Change_Filter_By_Price_Display_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since 1.0.0
	 * @param string $plugin_name The name of the plugin.
	 * @param string $version     The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since 1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Wc_Change_Filter_By_Price_Display_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Wc_Change_Filter_By_Price_Display_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/wc-change-filter-by-price-display-public.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since 1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Wc_Change_Filter_By_Price_Display_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Wc_Change_Filter_By_Price_Display_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/wc-change-filter-by-price-display-public.js', array( 'jquery' ), $this->version, false );

	}

	/**
	 * Add CSS for price slider based on setting.
	 *
	 * @since 1.0.0
	 */
	public function cfpd_wp_head() {

		$cfpd_color = get_option( 'cfpd_color', '' );
		if ( '' !== $cfpd_color ) {
			?>
			<style type="text/css">
			.widget_price_filter .ui-slider .ui-slider-range,
			.widget_price_filter .ui-slider .ui-slider-handle
			{
				background-color: <?php echo $cfpd_color; ?> !important;
			}
			</style>
			<?php
		}
	}

	/**
	 * Showing content before filter products by price widget.
	 *
	 * @since 1.0.0
	 */
	public function cfpd_woocommerce_widget_price_filter_start() {

		$cfpd_before = get_option( 'cfpd_content_before_filter_product_by_price', '' );
		if ( '' !== $cfpd_before ) {
			?>
			<div class="wc-before-filter-products-by-price-widget"><?php echo $cfpd_before; ?></div>
			<?php
		}
	}

	/**
	 * Setting step value in Filter Product by Price Widget.
	 *
	 * @since    1.0.0
	 */
	public function cfpd_woocommerce_widget_price_filter_end() {

		$cfpd_after = get_option( 'cfpd_content_after_filter_product_by_price', '' );
		if ( '' !== $cfpd_after ) {
			?>
			<div class="wc-before-filter-products-by-price-widget"><?php echo $cfpd_after; ?></div>
			<?php
		}
	}

	/**
	 * Setting step value in Filter Product by Price Widget.
	 *
	 * @param int $step Step for the slider.
	 * @since 1.0.0
	 */
	public function cfpd_woocommerce_price_filter_widget_step( $step ) {

		$cfpd_step = get_option( 'cfpd_step_price', '' );
		if ( '' !== $cfpd_step ) {
			$step = (int) $cfpd_step;
		}

		return $step;
	}

	/**
	 * Setting Minimum Price value in Filter Product by Price Widget.
	 *
	 * @param int $min Min Price.
	 * @since 1.0.0
	 */
	public function cfpd_woocommerce_price_filter_widget_min_amount( $min ) {

		$cfpd_min = get_option( 'cfpd_minimum_price', '' );
		if ( '' !== $cfpd_min ) {
			$min = $cfpd_min;
		}

		return $min;
	}

	/**
	 * Setting Maximum Price value in Filter Product by Price Widget.
	 *
	 * @param int $max Max Price.
	 * @since    1.0.0
	 */
	public function cfpd_woocommerce_price_filter_widget_max_amount( $max ) {

		$cfpd_max = get_option( 'cfpd_maximum_price', '' );
		if ( '' !== $cfpd_max ) {
			$max = $cfpd_max;
		}

		return $max;
	}

}
