<?php
/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              https://www.kartechify.com/
 * @since             1.0.0
 * @package           Wc_Change_Filter_By_Price_Display
 *
 * @wordpress-plugin
 * Plugin Name:       Extend Filter Products By Price Widget
 * Plugin URI:        https://kartechify.com/product/extend-filter-products-by-price-widget/
 * Description:       This plugins allows to change the display of Filter Products by Price widget on front end. You can set minimum & maximum price as well as the steps in price slider. Also, you can change the color of price slider and add more content before and after the widget display.
 * Version:           1.1
 * Author:            Kartik Parmar
 * Author URI:        https://www.kartechify.com/
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       wc-change-filter-by-price-display
 * Tested up to:         5.4
 * Requires PHP:         5.6
 * WC requires at least: 3.0.0
 * WC tested up to:      4.0
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

if ( ! function_exists( 'efpbpw_fs' ) ) {
    // Create a helper function for easy SDK access.
    function efpbpw_fs() {
        global $efpbpw_fs;

        if ( ! isset( $efpbpw_fs ) ) {
            // Include Freemius SDK.
            require_once dirname(__FILE__) . '/freemius/start.php';

            $efpbpw_fs = fs_dynamic_init( array(
                'id'                  => '6017',
                'slug'                => 'extend-filter-products-by-price-widget',
                'type'                => 'plugin',
                'public_key'          => 'pk_a6a30ea8fd3d38fa64691ece5fac8',
                'is_premium'          => false,
                'has_addons'          => false,
                'has_paid_plans'      => false,
                'menu'                => array(
                    'first-path'     => 'plugins.php',
                    'account'        => false,
                    'contact'        => false,
                ),
            ) );
        }

        return $efpbpw_fs;
    }

    // Init Freemius.
    efpbpw_fs();
    // Signal that SDK was initiated.
    do_action( 'efpbpw_fs_loaded' );
}

/**
 * Currently plugin version.
 * Start at version 1.0.0 and use SemVer - https://semver.org
 * Rename this for your plugin and update it as you release new versions.
 */
define( 'WC_CHANGE_FILTER_BY_PRICE_DISPLAY_VERSION', '1.1' );
define( 'CFPD_PLUGIN_BASENAME', plugin_basename( __FILE__ ) );

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-wc-change-filter-by-price-display-activator.php
 */
function activate_wc_change_filter_by_price_display() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-wc-change-filter-by-price-display-activator.php';
	Wc_Change_Filter_By_Price_Display_Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-wc-change-filter-by-price-display-deactivator.php
 */
function deactivate_wc_change_filter_by_price_display() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-wc-change-filter-by-price-display-deactivator.php';
	Wc_Change_Filter_By_Price_Display_Deactivator::deactivate();
}

register_activation_hook( __FILE__, 'activate_wc_change_filter_by_price_display' );
register_deactivation_hook( __FILE__, 'deactivate_wc_change_filter_by_price_display' );

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path( __FILE__ ) . 'includes/class-wc-change-filter-by-price-display.php';

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.0
 */
function run_wc_change_filter_by_price_display() {

	$plugin = new Wc_Change_Filter_By_Price_Display();
	$plugin->run();

}
run_wc_change_filter_by_price_display();
